==> huaweicloudsdkhss-3.1.99-py2.py3-none-any.whl: huaweicloudsdkhss/v5/model/vul_host_info_disabled_operate_types.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class VulHostInfoDisabledOperateTypes:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'operate_type': 'str',
        'reason': 'str'
    }

    attribute_map = {
        'operate_type': 'operate_type',
        'reason': 'reason'
    }

    def __init__(self, operate_type=None, reason=None):
        """VulHostInfoDisabledOperateTypes

        The model defined in huaweicloud sdk

        :param operate_type: 操作类型 - ignore : 忽略 - not_ignore : 取消忽略 - immediate_repair : 修复 - manual_repair: 人工修复 - verify : 验证 - add_to_whitelist : 加入白名单
        :type operate_type: str
        :param reason: 不可进行操作的原因
        :type reason: str
        """
        
        

        self._operate_type = None
        self._reason = None
        self.discriminator = None

        if operate_type is not None:
            self.operate_type = operate_type
        if reason is not None:
            self.reason = reason

    @property
    def operate_type(self):
        """Gets the operate_type of this VulHostInfoDisabledOperateTypes.

        操作类型 - ignore : 忽略 - not_ignore : 取消忽略 - immediate_repair : 修复 - manual_repair: 人工修复 - verify : 验证 - add_to_whitelist : 加入白名单

        :return: The operate_type of this VulHostInfoDisabledOperateTypes.
        :rtype: str
        """
        return self._operate_type

    @operate_type.setter
    def operate_type(self, operate_type):
        """Sets the operate_type of this VulHostInfoDisabledOperateTypes.

        操作类型 - ignore : 忽略 - not_ignore : 取消忽略 - immediate_repair : 修复 - manual_repair: 人工修复 - verify : 验证 - add_to_whitelist : 加入白名单

        :param operate_type: The operate_type of this VulHostInfoDisabledOperateTypes.
        :type operate_type: str
        """
        self._operate_type = operate_type

    @property
    def reason(self):
        """Gets the reason of this VulHostInfoDisabledOperateTypes.

        不可进行操作的原因

        :return: The reason of this VulHostInfoDisabledOperateTypes.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this VulHostInfoDisabledOperateTypes.

        不可进行操作的原因

        :param reason: The reason of this VulHostInfoDisabledOperateTypes.
        :type reason: str
        """
        self._reason = reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VulHostInfoDisabledOperateTypes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkhss-3.1.144-py2.py3-none-any.whl: huaweicloudsdkhss/v5/model/vul_host_info_disabled_operate_types.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class VulHostInfoDisabledOperateTypes:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'operate_type': 'str',
        'reason': 'str'
    }

    attribute_map = {
        'operate_type': 'operate_type',
        'reason': 'reason'
    }

    def __init__(self, operate_type=None, reason=None):
        r"""VulHostInfoDisabledOperateTypes

        The model defined in huaweicloud sdk

        :param operate_type: 操作类型 - ignore : 忽略 - not_ignore : 取消忽略 - immediate_repair : 修复 - manual_repair: 人工修复 - verify : 验证 - add_to_whitelist : 加入白名单
        :type operate_type: str
        :param reason: 不可进行操作的原因
        :type reason: str
        """
        
        

        self._operate_type = None
        self._reason = None
        self.discriminator = None

        if operate_type is not None:
            self.operate_type = operate_type
        if reason is not None:
            self.reason = reason

    @property
    def operate_type(self):
        r"""Gets the operate_type of this VulHostInfoDisabledOperateTypes.

        操作类型 - ignore : 忽略 - not_ignore : 取消忽略 - immediate_repair : 修复 - manual_repair: 人工修复 - verify : 验证 - add_to_whitelist : 加入白名单

        :return: The operate_type of this VulHostInfoDisabledOperateTypes.
        :rtype: str
        """
        return self._operate_type

    @operate_type.setter
    def operate_type(self, operate_type):
        r"""Sets the operate_type of this VulHostInfoDisabledOperateTypes.

        操作类型 - ignore : 忽略 - not_ignore : 取消忽略 - immediate_repair : 修复 - manual_repair: 人工修复 - verify : 验证 - add_to_whitelist : 加入白名单

        :param operate_type: The operate_type of this VulHostInfoDisabledOperateTypes.
        :type operate_type: str
        """
        self._operate_type = operate_type

    @property
    def reason(self):
        r"""Gets the reason of this VulHostInfoDisabledOperateTypes.

        不可进行操作的原因

        :return: The reason of this VulHostInfoDisabledOperateTypes.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        r"""Sets the reason of this VulHostInfoDisabledOperateTypes.

        不可进行操作的原因

        :param reason: The reason of this VulHostInfoDisabledOperateTypes.
        :type reason: str
        """
        self._reason = reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VulHostInfoDisabledOperateTypes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
